/*
 * Copyright (C) 2008 Google Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.database;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;

import com.entities.GymSet;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

/**
 * Simple notes database access helper class. Defines the basic CRUD operations
 * for the notepad example, and gives the ability to list all notes as well as
 * retrieve or modify a specific note.
 * 
 * This has been improved from the first version of this tutorial through the
 * addition of better error handling and also using returning a Cursor instead
 * of using a collection of inner classes (which is less scalable and not
 * recommended).
 */
public class SetDbAdapter {

    public static final String KEY_TITLE = "ex_date";
    public static final String KEY_BODY = "body";

    private static final String TAG = "NotesDbAdapter";
    private DatabaseHelper mDbHelper;
    private SQLiteDatabase mDb;
    
    /**
     * Database creation sql statement
     */
    private static final String GYMANGY_DB_CREATE = 
    	"create table sets (_id integer primary key autoincrement, ex_name integer, set_num integer, reps integer, weight integer, ex_date date, ex_time date);"; 
    
    private static final String DATABASE_NAME = "gym";
    private static final String DATABASE_TABLE = "sets";
    private static final int DATABASE_VERSION = 2;
	public static final String	EX_NAME	= "ex_name";
	public static final String	SET_NUM	= "set_num";
	public static final String	REPS	= "reps";
	public static final String	WEIGHT	= "weight";
	public static final String	REC_ID	= "_id";
	public static final String	EX_DATE	= "ex_date";
	public static final String	EX_TIME	= "ex_time";

    private final Context mCtx;

    private static class DatabaseHelper extends SQLiteOpenHelper {

        DatabaseHelper(Context context) {
            super(context, DATABASE_NAME, null, DATABASE_VERSION);
        }

        @Override
        public void onCreate(SQLiteDatabase db) {
            db.execSQL("DROP TABLE sets;");

            db.execSQL(GYMANGY_DB_CREATE);
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
            Log.w(TAG, "Upgrading database from version " + oldVersion + " to "
                    + newVersion + ", which will destroy all old data");
            db.execSQL("DROP TABLE IF EXISTS notes");
            onCreate(db);
        }
    }

    /**
     * Constructor - takes the context to allow the database to be
     * opened/created
     * 
     * @param ctx the Context within which to work
     */
    public SetDbAdapter(Context ctx) {
        this.mCtx = ctx;
    }

    /**
     * Open the gym database. If it cannot be opened, try to create a new
     * instance of the database. If it cannot be created, throw an exception to
     * signal the failure
     * 
     * @return this (self reference, allowing this to be chained in an
     *         initialization call)
     * @throws SQLException if the database could be neither opened or created
     */
    public SetDbAdapter open() throws SQLException {
        mDbHelper = new DatabaseHelper(mCtx);
        mDb = mDbHelper.getWritableDatabase();
        return this;
    }
    
    public void close() {
        mDbHelper.close();
    }


        /**
     * 
     * @param exersiceName name of the exersice
     * @param list list of sets
     * @return
     */
    public void createNewRecord(String exersiceName, ArrayList<GymSet> list, Date date){
    	ContentValues initialValues = new ContentValues();
        for(GymSet el: list){
        	initialValues.put(EX_NAME, exersiceName);
            initialValues.put(SET_NUM, el.getSetID());
            initialValues.put(REPS, el.getRepeats());
            initialValues.put(WEIGHT, el.getWeight());
            SimpleDateFormat formatter = new SimpleDateFormat("dd.MM.yyy");
            initialValues.put(EX_DATE, formatter.format(date));
            initialValues.put(EX_TIME, date.toLocaleString());
            mDb.insert(DATABASE_TABLE, null, initialValues);
        }
    }
    
    public Cursor fetchAllNotes() {

        return mDb.query(DATABASE_TABLE, new String[] {REC_ID, EX_NAME, SET_NUM,
                REPS, WEIGHT}, null, null, null, null, null);
    }
    
    public Cursor getDateForExersices(){
    	return mDb.query(DATABASE_TABLE, new String[] {REC_ID, EX_DATE}, null, null, EX_DATE, null, null);
    }
    
    public Cursor getExersiceForDate(String date){
    	return mDb.query(DATABASE_TABLE, new String[] {REC_ID, EX_NAME, SET_NUM, REPS, WEIGHT }, EX_DATE + " = '" + date + "'"  , null, null, null, null);
    }
}
